import 'package:flutter/material.dart';
import 'package:shimmer/shimmer.dart';

class ProtonImage extends StatelessWidget {
  final String path;
  final double height;
  final double radius;

  final BoxFit imgBoxfit;
  final double aspectRatio;
  final Color baseColor;
  final Color highlightColor;
  final Color backgroundColor;

  const ProtonImage({
    super.key,
    required this.path,
    required this.height,
    required this.radius,
    this.imgBoxfit = BoxFit.cover,
    this.aspectRatio = (1 / 1),
    this.baseColor = Colors.white24,
    this.highlightColor = Colors.white54,
    this.backgroundColor = Colors.white,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: height,
      child: AspectRatio(
        aspectRatio: aspectRatio,
        child: Stack(
          children: [
            Transform.scale(
              scale: 0.990,
              child: Shimmer.fromColors(
                baseColor: baseColor,
                highlightColor: highlightColor,
                child: Container(
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(radius),
                    color: backgroundColor,
                  ),
                ),
              ),
            ),
            Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(radius),
                image: DecorationImage(
                  fit: imgBoxfit,
                  image: NetworkImage(path),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
